###########################
restfulgrok
###########################

RESTful interface for grok (and five.grok).


Issues/contribute
=================

Report any issues at the `github project page <restfulgrok>`_, and feel free
to add your own guides/experiences to the wiki, and to contribute changes using
pull requests.


Install
=======

::

    $ pip install restfulgrok



Usage
=====

TODO



.. _`restfulgrok`: https://github.com/espenak/restfulgrok
